__all__ = ["__title__", "__summary__", "__version__", "__author__", "__copyright__"]

__title__ = "wnpoly"
__summary__ = "Python project to compute polynomials useful for Webnucleo projects"
__version__ = "1.1.0"
__author__ = "Clemson University"
__copyright__ = "Clemson University, 2023"
